#
# spec file for package enca
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           enca
Version:        1.19
Release:        2.10
Summary:        Detects encoding of text files
License:        GPL-2.0-only
Group:          Productivity/Other
URL:            https://cihar.com/software/enca/
Source:         https://dl.cihar.com/%{name}/%{name}-%{version}.tar.xz
Source1:        baselibs.conf
BuildRequires:  pkgconfig
Requires:       sed

%description
Enca is an Extremely Naive Charset Analyser. It detects character set and
encoding of text files and can also convert them to other encodings using
either a built-in converter or external libraries and tools like libiconv,
librecode, or cstocs.

Currently, it has support for Belarussian, Bulgarian, Croatian, Czech,
Estonian, Latvian, Lithuanian, Polish, Russian, Slovak, Slovene, Ukrainian,
Chinese, and some multibyte encodings (mostly variants of Unicode)
independent on the language.

This package also contains shared Enca library other programs can make use of.

Install Enca if you need to cope with text files of dubious origin
and unknown encoding and convert them to some reasonable encoding.

%package -n libenca0
Summary:        Header files and libraries for Enca development
Group:          System/Libraries

%description -n libenca0
The enca-devel package contains the static libraries and header files
for writing programs using the Extremely Naive Charset Analyser library,
and its API documentation.

Install enca-devel if you are going to create applications using the Enca
library.

%package devel
Summary:        Header files and libraries for Enca development
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libenca0 = %{version}

%description devel
The enca-devel package contains the static libraries and header files
for writing programs using the Extremely Naive Charset Analyser library,
and its API documentation.

Install enca-devel if you are going to create applications using the Enca
library.

%prep
%setup -q

%build
%configure --disable-static --without-librecode
%make_build

%install
%make_install
# the .la file is not needed without static libs
rm %{buildroot}/%{_libdir}/libenca.la

%post -n libenca0 -p /sbin/ldconfig
%postun -n libenca0 -p /sbin/ldconfig

%files
%license COPYING
%doc AUTHORS ChangeLog* FAQ README THANKS TODO
%{_bindir}/enca
%{_bindir}/enconv
%{_libexecdir}/enca
%{_mandir}/man1/enca.1%{?ext_man}
%{_mandir}/man1/enconv.1%{?ext_man}

%files -n libenca0
%{_libdir}/libenca.so.0*

%files devel
%{_datadir}/gtk-doc/html/*
# Own these repositories to not depend on gtk-doc while building:
%dir %{_datadir}/gtk-doc
%dir %{_datadir}/gtk-doc/html
%{_includedir}/enca.h
%{_libdir}/libenca.so
%{_libdir}/pkgconfig/enca.pc

%changelog
* Fri May 13 2022 Dominique Leuenberger <dimstar@opensuse.org>
- URL -> https.
- Run spec-cleaner: mainly: package LICENSE as license, not doc.
* Wed Nov  8 2017 aavindraa@gmail.com
- update to version 1.19
  + fix possible memory leak
  + make utf-8 detection work even on one character
- includes changes from 1.18
  + fix installation of devhelp documentation
- includes changes from 1.17
  + Fixed conversion of GB2312 encoding with iconv
  + Fixed iconv conversion on OSX
  + Fixed execution of external converters with ACLs
  + Documentation improvements
- cleanup with spec-cleaner
- use %%make_install macro
- list binaries and man pages explicitly
* Sun Nov  8 2015 p.drouand@gmail.com
- Update to version 1.16
  * Fixed typo in Belarusian language name
  * Added aliases for Chinese and Yugoslavian languages
* Thu Oct  3 2013 mcihar@suse.cz
- Fixed upstream URL in spec file
* Mon Sep 30 2013 mcihar@suse.cz
- update to 1.15:
  + Documentation improvement
  + Development moved to GitHub
  + Do not use deprecated autoconf macros
* Tue Mar 26 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Sun Dec 16 2012 lars@linux-schulserver.de
- update to 1.14:
  + Allow standard names for belarusian and slovenian languages,
    thanks to Branislav Geržo for suggestion.
  + Reset strictness when check buffer less than file size,
    thanks to Sam Liao.
  + Fixed typos in man page, thanks to A. Costa.
* Wed Feb 15 2012 lars@linux-schulserver.de
- fix license to be in spdx format
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant/obsolete tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
* Thu Apr 14 2011 toddrme2178@gmail.com
- added 32bit compatibility libraries
- removed tests for obsolete openSUSE versions
* Wed May  5 2010 mcihar@suse.cz
- change buildrequire to pkgconfig to build also on other distros
* Wed May  5 2010 mcihar@suse.cz
- update to 1.13
* Sat Apr 24 2010 coolo@novell.com
- buildreqire pkg-config to fix provides
* Thu Oct 29 2009 mcihar@suse.cz
- update to version 1.12
* Fri Sep 25 2009 mcihar@suse.cz
- update to version 1.11
* Tue Aug 25 2009 mcihar@suse.cz
- build without recode support
* Tue Aug 25 2009 mcihar@suse.cz
- update to new upstream and version 1.10
* Tue Aug 11 2009 sbrabec@suse.cz
- Split according to shared library packaging rules.
* Mon Sep 22 2008 lars@linux-schulserver.de
- moved to Education base repository
* Mon Mar 17 2008 lars@linux-schulserver.de
- build for openSUSE-Education
- beautify specfile
- don't build static binaries
- Require glibc-devel for the devel package
- own %%{_datadir}/gtk-doc/html to avoid gtk-doc dependency
* Sat Sep  1 2007 16:45:00 CET - michel.sylvan@gmail.com
- Strip debugging info into separate subpackage
* Wed Aug 29 2007 14:35:00 CET  - michel.sylvan@gmail.com
- Initial package
